<div id="footer">
	<br />
	<h2 id="subtitle">Debian Live Project <a href="mailto:debian-live@lists.debian.org">&lt;debian-live@lists.debian.org&gt;</a> &mdash; <a href="http://live.debian.net/devel/live-build">live-build</a>, version VERSION &mdash; <a href="http://live.debian.net/legal.html">Legal information</a></h2>
	<br />
</div>

</body>
</html>
