<br />

<h3>Your build 'BUILD' was recorded and will be processed soon. Depending on the options you have selected, a build attempt generally takes between 5 and 20 minutes to complete. Currently there are 'QUEUENUM' pending build(s) to be processed ahead of your request. You will be notified by email when the attempt has completed.</h3>

<h3>Your build will be available at: <a href="SERVER/BUILD/">SERVER/BUILD/</a>.</h3>

<fieldset>

<legend><b>Options</b></legend>

<b>Standard options</b>

<table>
	<tr><td>Email: </td><td>EMAIL</td></tr>
	<tr><td>--binary-image: </td><td>LB_BINARY_IMAGES</td></tr>
	<tr><td>--distribution: </td><td>LB_DISTRIBUTION</td></tr>
	<tr><td>--config: </td><td>_LB_CONFIG</td></tr>
	<tr><td>cgipackages.list.chroot: </td><td>_LB_CGIPACKAGES</td><tr>
</table>

<b>Advanced bootstrap options</b>

<table>
	<tr><td>--architectures: </td><td>LB_ARCHITECTURES</td></tr>
	<tr><td>--bootstrap-flavour: </td><td>LB_BOOTSTRAP_FLAVOUR</td></tr>
	<tr><td>--archive-areas: </td><td>LB_ARCHIVE_AREAS</td></tr>
</table>

<b>Advanced chroot options</b>

<table>
	<tr><td>--chroot-fileystem: </td><td>LB_CHROOT_FILESYSTEM</td></tr>
	<tr><td>--linux-flavours: </td><td>LB_LINUX_FLAVOURS</td></tr>
	<tr><td>--security: </td><td>LB_SECURITY</td></tr>
</table>

<b>Advanced binary options</b>

<table>
	<tr><td>--apt-indices: </td><td>LB_BINARY_INDICES</td></tr>
	<tr><td>--bootappend-live: </td><td>LB_BOOTAPPEND_LIVE</td></tr>
	<tr><td>--bootloader: </td><td>LB_BOOTLOADER</td></tr>
	<tr><td>--debian-installer: </td><td>LB_DEBIAN_INSTALLER</td></tr>
	<tr><td>--bootappend-install: </td><td>LB_BOOTAPPEND_INSTALL</td></tr>
	<tr><td>--iso-application: </td><td>LB_ISO_APPLICATION</td></tr>
	<tr><td>--iso-preparer: </td><td>LB_ISO_PREPARER</td></tr>
	<tr><td>--iso-publisher: </td><td>LB_ISO_PUBLISHER</td></tr>
	<tr><td>--iso-volume: </td><td>LB_ISO_VOLUME</td></tr>
	<tr><td>--memtest: </td><td>LB_MEMTEST</td></tr>
	<tr><td>--net-path: </td><td>LB_NET_ROOT_PATH</td></tr>
	<tr><td>--net-server: </td><td>LB_NET_ROOT_SERVER</td></tr>
</table>

<b>Advanced source options</b>

<table>
	<tr><td>--source: </td><td>LB_SOURCE</td></tr>
	<tr><td>--source-images: </td><td>LB_SOURCE_IMAGES</td></tr>
</table>

</fieldset>

<br />

<h3>Thank you for your submission.</h3>
