#!/bin/sh

## live-build(7) - System Build Scripts
## Copyright (C) 2006-2012 Daniel Baumann <daniel@debian.org>
##
## This program comes with ABSOLUTELY NO WARRANTY; for details see COPYING.
## This is free software, and you are welcome to redistribute it
## under certain conditions; see COPYING for details.


# Debian releases
RELEASE_squeeze="6.0.5"
RELEASE_wheezy="7.0.0"
RELEASE_jessie="8"
RELEASE_sid="unstable"

# Progress releases
RELEASE_artax="1.0"
RELEASE_baureo="2.0"
RELEASE_charon="unstable"

# Ubuntu releases
RELEASE_hardy="8.04"		# LTS: 2013-04-01
RELEASE_lucid="10.04"		# LTS: 2015-04-01
RELEASE_natty="11.04"		# 2012-10-01
RELEASE_oneiric="11.10"		# 2013-04-01
RELEASE_precise="12.04"		# LTS: 2017-04-01
RELEASE_quantal="12.10"		# 2014-04-01
