
<h3>Submit your parameters (<b>working</b> email address is required) to generate your very own Debian Live system.</h3>

<form action="live-build" method="get">

<fieldset>

<legend><b>Options</b></legend>

<table>
	<tr>
		<td><label for="Email">Email Address:</label> </td>
		<td><input id="Email" name="email" maxlength="50" size="50" type="text" /></td>
	</tr>
</table>

<span id="click_1" onmouseover='javascript:objectOver(this)' onmouseout='javascript:objectOut(this)' onclick='javascript:collapse(1,"<b>Standard options</b>")'>
	<b>Standard options</b><small>&nbsp;(click to collapse)</small>
	<br />
</span>

<div id="text_1" style='margin-left:0;display:block'>
	<table>
		<tr>
			<td><label for="Binary_Images">--binary-images:</label> </td>
			<td>
				<select id="Binary_Images" name="binary_images" size="1">
					<option value="iso">iso</option>
					<option selected value="iso-hybrid">iso-hybrid</option>
					<option value="net">net</option>
					<option value="tar">tar</option>
					<option value="hdd">hdd</option>
					<option value="virtual-hdd">virtual-hdd</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Distribution">--distribution:</label> </td>
			<td>
				<select id="Distribution" name="distribution" size="1">
					<option selected value="squeeze">squeeze</option>
					<option value="wheezy">wheezy</option>
					<option value="sid">sid</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Config">--config:</label> </td>
			<td>
				<select id="Config" name="config" size="1" >
					<option value="config-gnome-desktop.git">GNOME Desktop</option>
					<option value="config-kde-desktop.git">KDE Desktop</option>
					<option value="config-lxde-desktop.git">LXDE Desktop</option>
					<option value="config-rescue.git">Rescue</option>
					<option selected value="config-standard.git">Standard</option>
					<option value="config-xfce-desktop.git">Xfce Desktop</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Packages">cgipackages.list.chroot:</label> </td>
			<td><input id="Packages" name="cgipackages" maxlength="256" size="50" type="text" /></td>
		</tr>
	</table>
</div>

<span id="click_2" onmouseover='javascript:objectOver(this)' onmouseout='javascript:objectOut(this)' onclick='javascript:collapse(2,"<b>Advanced bootstrap options</b>")'>
	<b>Advanced bootstrap options</b><small>&nbsp;(click to expand)</small>
	<br />
</span>

<div id="text_2" style='margin-left:0;display:none'>
	<table>
		<tr>
			<td><label for="Architectures">--architectures:</label> </td>
			<td>
				<select id="Architectures" name="architectures" size="1">
					<option value="amd64">amd64</option>
					<option selected value="i386">i386</option>
				</select>
			</td>
		</tr>
		<!-- LIVE_DISTRIBUTION -->
		<!-- LIVE_DISTRIBUTION_CONFIG -->
		<tr>
			<td><label for="Bootstrap_Flavour">--bootstrap-flavour:</label> </td>
			<td>
				<select id="Bootstrap_Flavour" name="bootstrap_flavour" size="1">
					<option value="minimal">minimal</option>
					<option selected value="standard">standard</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Archive_Areas">--archive-areas:</label> </td>
			<td><input id="Archive_Areas" name="archive_areas" maxlength="128" size="50" type="text" value="main" readonly /></td>
		</tr>
	</table>
</div>

<span id="click_3" onmouseover='javascript:objectOver(this)' onmouseout='javascript:objectOut(this)' onclick='javascript:collapse(3,"<b>Advanced chroot options</b>")'>
	<b>Advanced chroot options</b><small>&nbsp;(click to expand)</small>
	<br />
</span>

<div id="text_3" style='margin-left:0;display:none'>
	<table>
		<tr>
			<td><label for="Chroot_Filesystem">--chroot-filesystem:</label> </td>
			<td>
				<select id="Chroot_Filesystem" name="chroot_filesystem" size="1">
					<option value="ext2">ext2</option>
					<option value="plain">plain</option>
					<option selected value="squashfs">squashfs</option>
				</select>
			</td>
		</tr>
		<!-- LIVE_HOOKS -->
		<!-- LIVE_INTERACTIVE -->
		<!-- LIVE_KEYRING_PACKAGES -->
		<!-- LIVE_LANGUAGE -->
		<tr>
			<td><label for="Linux_Flavours">--linux-flavours:</label> </td>
			<td>
				<select id="Linux_Flavours" name="linux_flavours" size="1">
					<option selected value="486">486</option>
					<option value="686">686</option>
					<option value="686-pae">686-pae</option>
					<option value="amd64">amd64</option>
					<option value="k7">k7</option>
					<option value="vserver-686">vserver-686</option>
					<option value="vserver-k7">vserver-k7</option>
					<option value="xen-686">xen-686</option>
				</select>
			</td>
		</tr>
		<!-- LIVE_LINUX_PACKAGES -->
		<tr>
			<td><label for="Security">--security:</label> </td>
			<td>
				<select id="Security" name="security" size="1">
					<option selected value="true">true</option>
					<option value="false">false</option>
				</select>
			</td>
		</tr>
	</table>
</div>

<span id="click_4" onmouseover='javascript:objectOver(this)' onmouseout='javascript:objectOut(this)' onclick='javascript:collapse(4,"<b>Advanced binary options</b>")'>
	<b>Advanced binary options</b><small>&nbsp;(click to expand)</small>
	<br />
</span>

<div id="text_4" style='margin-left:0;display:none'>
	<table>
		<!-- LIVE_BINARY_IMAGES -->
		<tr>
			<td><label for="Apt_Indices">--apt-indices:</label> </td>
			<td>
				<select id="Apt_Indices" name="binary_indices" size="1">
					<option selected value="true">true</option>
					<option value="false">false</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Bootappend_Live">--bootappend-live:</label> </td>
			<td><input id="Bootappend_Live" name="bootappend_live" maxlength="256" size="50" type="text" value="" /></td>
		</tr>
		<tr>
			<td><label for="Bootloader">--bootloader:</label> </td>
			<td>
				<select id="Bootloader" name="bootloader" size="1">
					<option value="grub">grub</option>
					<option selected value="syslinux">syslinux</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Debian_Installer">--debian-installer:</label> </td>
			<td>
				<select id="Debian_Installer" name="debian_installer" size="1">
					<option value="true">true</option>
					<option selected value="false">false</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Bootappend_Install">--bootappend-install:</label> </td>
			<td><input id="Bootappend_Install" name="bootappend_install" maxlength="256" size="50" type="text" value="" /></td>
		</tr>
		<!-- LIVE_GRUB_SPLASH -->
		<tr>
			<td><label for="Iso_Application">--iso-application:</label> </td>
			<td><input id="Iso_Application" name="iso_application" maxlength="128" size="50" type="text" value="Debian Live" /></td>
		</tr>
		<tr>
			<td><label for="Iso_Preparer">--iso-preparer:</label> </td>
			<td><input id="Iso_Preparer" name="iso_preparer" maxlength="128" size="50" type="text" value="live-build; http://packages.qa.debian.org/live-build" /></td>
		</tr>
		<tr>
			<td><label for="Iso_Publisher">--iso-publisher:</label> </td>
			<td><input id="Iso_Publisher" name="iso_publisher" maxlength="128" size="50" type="text" value="Debian Live project; http://live.debian.net/; debian-live@lists.debian.org" /></td>
		</tr>
		<tr>
			<td><label for="Iso_Volume">--iso-volume:</label> </td>
			<td><input id="Iso_Volume" name="iso_volume" maxlength="128" size="50" type="text" value="Debian Live DATE" /></td>
		</tr>
		<tr>
			<td><label for="Memtest">--memtest:</label> </td>
			<td>
				<select id="Memtest" name="memtest" size="1">
					<option value="memtest86">memtest86</option>
					<option selected value="memtest86+">memtest86+</option>
					<option value="none">none</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Net_Path">--net-path:</label> </td>
			<td><input id="Net_Path" name="net_path" maxlength="256" size="50" type="text" value="/srv/debian-live" /></td>
		</tr>
		<tr>
			<td><label for="Net_Server">--net-server:</label> </td>
			<td><input id="Net_Server" name="net_server" maxlength="15" size="50" type="text" value="192.168.1.1" /></td>
		</tr>
		<!-- LIVE_SYSLINUX_SPLASH -->
	</table>
</div>

<span id="click_5" onmouseover='javascript:objectOver(this)' onmouseout='javascript:objectOut(this)' onclick='javascript:collapse(5,"<b>Advanced source options</b>")'>
	<b>Advanced source options</b><small>&nbsp;(click to expand)</small>
	<br />
</span>

<div id="text_5" style='margin-left:0;display:none'>
	<table>
		<tr>
			<td><label for="Source">--source:</label> </td>
			<td>
				<select id="Source" name="source" size="1">
					<option value="true">true</option>
					<option selected value="false">false</option>
				</select>
			</td>
		</tr>
		<tr>
			<td><label for="Source_Images">--source-images:</label> </td>
			<td>
				<select id="Source_Images" name="source_images" size="1">
					<option value="iso">iso</option>
					<option value="net">net</option>
					<option selected value="tar">tar</option>
					<option value="hdd">hdd</option>
				</select>
			</td>
		</tr>
	</table>
</div>

</fieldset>

<br />

<input type="reset" value="Reset" />
&nbsp;
<input type="submit" value="Submit" />
&nbsp;

</form>
